import { Command, flags } from '@oclif/command';
/**
 * User's name and email pull from git settings
 */
interface GitSettings {
    name: string;
    email: string;
}
/**
 * Defines data that will be replaced. Key is what will be replaced, value is
 * the replacement
 */
interface Replacement {
    [key: string]: string;
    author: string;
    copyright: string;
    createDate: string;
    email: string;
    item: string;
    Item: string;
    ITEM: string;
    items: string;
    Items: string;
    ITEMS: string;
    name: string;
    Name: string;
    NAME: string;
    url: string;
}
export default class Create extends Command {
    /**
     * Description to display via CLI
     *
     * @var  {string}
     */
    static description: string;
    /**
     * List of examples to display when just the main command is ran
     *
     * @var  {string[]}
     */
    static examples: string[];
    static flags: {
        author: flags.IOptionFlag<string | undefined>;
        createDate: flags.IOptionFlag<string | undefined>;
        email: flags.IOptionFlag<string | undefined>;
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        url: flags.IOptionFlag<string | undefined>;
        useGit: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        template: flags.IOptionFlag<string | undefined>;
        copyright: flags.IOptionFlag<string | undefined>;
    };
    /**
     * List of arguments specific to this command
     *
     * @var  {Arg[]}
     */
    static args: {
        name: string;
        description: string;
        required: boolean;
    }[];
    run(): Promise<void>;
    /**
     * Create object replacement data based on CLI arguments
     *
     * @return  {Replacement}  Key is what will be replaced, value is the
     *                         replacement
     */
    protected createReplacementData(): Replacement;
    /**
     * Pull name and email from user's git configuration
     *
     * @return  {GitSettings}  Object containing user's name and email from git
     *                         settings
     */
    protected getGitSettings(): GitSettings;
    /**
     * Recursively get rename all files and folders containing placeholder names
     * in newly generated component folder
     *
     * @param   {string}  path  Path to start list operation in
     * @param   {string}  name  Name of component without com_ prefix
     * @param   {string}  view  Name of view to rename
     *
     * @return  {void}
     */
    protected renameFiles(path: string, name: string, view: string): void;
    /**
     * Recursively replace placeholders with data provided by the user
     *
     * @param   {string}  path  Path to current directory context
     *
     * @return  {void}
     */
    protected replaceData(path: string): void;
}
export {};
